## v1.1.0 (December 12, 2025)

Full Changelog: https://github.com/atlanhq/application-sdk/compare/v1.0.4...v1.1.0

### Features

- Add Atlan Attributes to Temporal Runs (#880) (by @saig214 in [8a85a24](https://github.com/atlanhq/application-sdk/commit/8a85a24))
